==> hubzero-cms-1.2_1.2.18.orig.tar.gz: hubzero-cms-1.2-1.2.18/cms/plugins/resources/groups/views/display/tmpl/mini.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

if ($this->group->get('logo'))
{
	$config = JComponentHelper::getParams('com_groups');
	$logo = DS . trim($config->get('uploadpath', '/site/groups'), DS) . DS . $this->group->get('gidNumber') . DS . $this->group->get('logo');
}
else 
{
	$logo = ''; //'/components/com_groups/assets/img/group_default_logo.png';
}
?>
<div id="group-owner" class="container">
	<h3><?php echo $this->escape(stripslashes($this->group->get('description'))); ?></h3>
	<div class="group-content">
<?php if ($logo) { ?>
		<p class="group-img">
			<a href="<?php echo JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn')); ?>">
				<img src="<?php echo $logo; ?>" width="50" alt="<?php echo $this->escape(stripslashes($this->group->get('description'))); ?> group image" />
			</a>
		</p>
		<p class="group-description group-withlogo"><?php echo JText::sprintf('This resource belongs to the %s group.', '<a href="' . JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn')) . '">' . $this->escape(stripslashes($this->group->get('description'))) . '</a>'); ?></p>
<?php } else { ?>
		<p class="group-description"><?php echo JText::sprintf('This resource belongs to the %s group.', '<a href="' . JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn')) . '">' . $this->escape(stripslashes($this->group->get('description'))) . '</a>'); ?></p>
<?php } ?>
	</div>
</div>

==> hubzero-cms-1.2.2_1.2.2.4.orig.tar.gz: hubzero-cms-1.2.2-1.2.2.4/cms/plugins/resources/groups/views/display/tmpl/mini.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

$logo = $this->group->getLogo();
?>
<div id="group-owner" class="container">
	<h3><?php echo $this->escape(stripslashes($this->group->get('description'))); ?></h3>
	<div class="group-content">
<?php if ($logo) { ?>
		<p class="group-img">
			<a href="<?php echo JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn')); ?>">
				<img src="<?php echo $logo; ?>" width="50" alt="<?php echo $this->escape(stripslashes($this->group->get('description'))); ?> group image" />
			</a>
		</p>
		<p class="group-description group-withlogo"><?php echo JText::sprintf('This resource belongs to the %s group.', '<a href="' . JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn')) . '">' . $this->escape(stripslashes($this->group->get('description'))) . '</a>'); ?></p>
<?php } else { ?>
		<p class="group-description"><?php echo JText::sprintf('This resource belongs to the %s group.', '<a href="' . JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn')) . '">' . $this->escape(stripslashes($this->group->get('description'))) . '</a>'); ?></p>
<?php } ?>
	</div>
</div>
